# Depack

Extract files from any type of archive in command line.

## Quick Start
### install
```bash
pip install depack
```

### decompress file
```bash
depack ./test.zip
```
or
```bash
unpack ./test.zip
```

### compress file
```bash
depack --create test.zip ./test_folder
```

## Reference
https://github.com/wummel/patool